Index: trunk/VUT/work/TestCullingTerrain/TerrainContentGenerator.cpp
===================================================================
--- trunk/VUT/work/TestCullingTerrain/TerrainContentGenerator.cpp	(revision 82)
+++ trunk/VUT/work/TestCullingTerrain/TerrainContentGenerator.cpp	(revision 84)
@@ -87,4 +87,9 @@
 	mMaxHeight = maxHeight;
 }
+//-----------------------------------------------------------------------
+int TerrainContentGenerator::GetObjectCount()
+{
+	return mCount;
+}
 
 } // namespace Ogre
Index: trunk/VUT/work/TestCullingTerrain/TerrainContentGenerator.h
===================================================================
--- trunk/VUT/work/TestCullingTerrain/TerrainContentGenerator.h	(revision 81)
+++ trunk/VUT/work/TestCullingTerrain/TerrainContentGenerator.h	(revision 84)
@@ -34,4 +34,5 @@
 
 	void SetMaxHeight(Real maxHeight);
+	int GetObjectCount();
 
 protected:
Index: trunk/VUT/work/TestCullingTerrain/TestCullingTerrainApplication.h
===================================================================
--- trunk/VUT/work/TestCullingTerrain/TestCullingTerrainApplication.h	(revision 82)
+++ trunk/VUT/work/TestCullingTerrain/TestCullingTerrainApplication.h	(revision 84)
@@ -79,6 +79,7 @@
     OverlayElement *mTraversedNodesInfo;
 	OverlayElement *mHierarchyNodesInfo;
-	OverlayElement *mSceneNodesInfo;
+	//OverlayElement *mSceneNodesInfo;
 	OverlayElement *mRenderedNodesInfo;
+	OverlayElement *mNumObjectsInfo;
 
 	SceneNode *mCurrentObject;         // The newly created object
Index: trunk/VUT/work/TestCulling/TestCullingApplication.cpp
===================================================================
--- trunk/VUT/work/TestCulling/TestCullingApplication.cpp	(revision 82)
+++ trunk/VUT/work/TestCulling/TestCullingApplication.cpp	(revision 84)
@@ -119,4 +119,5 @@
 	mAlgorithmInfo = OverlayManager::getSingleton().getOverlayElement("Example/Visibility/AlgorithmInfo");
 	mThresholdInfo = OverlayManager::getSingleton().getOverlayElement("Example/Visibility/ThresholdInfo");
+	
 	mFrustumCulledNodesInfo = OverlayManager::getSingleton().getOverlayElement("Example/Visibility/FrustumCulledNodesInfo");
 	mQueryCulledNodesInfo = OverlayManager::getSingleton().getOverlayElement("Example/Visibility/QueryCulledNodesInfo");
@@ -124,4 +125,5 @@
 	mHierarchyNodesInfo = OverlayManager::getSingleton().getOverlayElement("Example/Visibility/HierarchyNodesInfo");
 	mRenderedNodesInfo = OverlayManager::getSingleton().getOverlayElement("Example/Visibility/RenderedNodesInfo");
+	mNumObjectsInfo = OverlayManager::getSingleton().getOverlayElement("Example/Visibility/NumObjectsInfo");
 
 	mAlgorithmInfo->setCaption(": " + mCurrentAlgorithmCaptions[mCurrentAlgorithm]);
@@ -132,4 +134,5 @@
 	mHierarchyNodesInfo->setCaption(": 0");
 	mRenderedNodesInfo->setCaption(": 0");
+	mNumObjectsInfo->setCaption(": 0");
 
     pOver->show();
@@ -254,4 +257,7 @@
 	mSceneMgr->getOption("NumRenderedNodes", &opt); sprintf(str,": %d", opt); 
 	mRenderedNodesInfo->setCaption(str);
+
+	sprintf(str,": %d", mTerrainContentGenerator->GetObjectCount()); 
+	mNumObjectsInfo->setCaption(str);
 }
 //-----------------------------------------------------------------------
Index: trunk/VUT/work/TestCulling/TestCullingApplication.h
===================================================================
--- trunk/VUT/work/TestCulling/TestCullingApplication.h	(revision 79)
+++ trunk/VUT/work/TestCulling/TestCullingApplication.h	(revision 84)
@@ -81,4 +81,5 @@
 	OverlayElement *mHierarchyNodesInfo;
 	OverlayElement *mRenderedNodesInfo;
+	OverlayElement *mNumObjectsInfo;
 };
 
Index: trunk/VUT/Ogre/resources/VisibilityDemo.overlay
===================================================================
--- trunk/VUT/Ogre/resources/VisibilityDemo.overlay	(revision 74)
+++ trunk/VUT/Ogre/resources/VisibilityDemo.overlay	(revision 84)
@@ -87,5 +87,5 @@
 		top 5
 		width 450
-		height 90
+		height 105
 		material Core/StatsBlockCenter
         	border_size 1 1 1 1
@@ -230,4 +230,30 @@
 			colour_bottom 0.3 0.5 0.3
 		}
+		element TextArea(Example/Visibility/NumObjects)
+		{
+			metrics_mode pixels
+			left 5
+			top 80
+			width 180
+			height 30
+			font_name TrebuchetMSBold
+			char_height 16
+			caption Number of objects
+			colour_top 0.5 0.7 0.5
+			colour_bottom 0.3 0.5 0.3
+		}	
+		element TextArea(Example/Visibility/NumObjectsInfo)
+		{
+			metrics_mode pixels
+			left 180
+			top 80
+			width 90
+			height 30
+			font_name TrebuchetMSBold
+			char_height 16
+			caption :
+			colour_top 0.5 0.7 0.5
+			colour_bottom 0.3 0.5 0.3
+		}
 
 

Index: trunk/VUT/work/TestCullingTerrain/TestCullingTerrainApplication.cpp
===================================================================
--- trunk/VUT/work/TestCullingTerrain/TestCullingTerrainApplication.cpp	(revision 82)
+++ trunk/VUT/work/TestCullingTerrain/TestCullingTerrainApplication.cpp	(revision 84)
@@ -97,5 +97,6 @@
 	mTerrainContentGenerator = new TerrainContentGenerator(mSceneMgr);
 	mTerrainContentGenerator->GenerateScene(300, "robot.mesh");
 	// no limitations now: the user can set objects also on peaks
 	mTerrainContentGenerator->SetMaxHeight(5000); 
 }
@@ -165,4 +166,5 @@
 	mAlgorithmInfo = OverlayManager::getSingleton().getOverlayElement("Example/Visibility/AlgorithmInfo");
 	mThresholdInfo = OverlayManager::getSingleton().getOverlayElement("Example/Visibility/ThresholdInfo");
+	
 	mFrustumCulledNodesInfo = OverlayManager::getSingleton().getOverlayElement("Example/Visibility/FrustumCulledNodesInfo");
 	mQueryCulledNodesInfo = OverlayManager::getSingleton().getOverlayElement("Example/Visibility/QueryCulledNodesInfo");
@@ -170,4 +172,5 @@
 	mHierarchyNodesInfo = OverlayManager::getSingleton().getOverlayElement("Example/Visibility/HierarchyNodesInfo");
 	mRenderedNodesInfo = OverlayManager::getSingleton().getOverlayElement("Example/Visibility/RenderedNodesInfo");
+	mNumObjectsInfo = OverlayManager::getSingleton().getOverlayElement("Example/Visibility/NumObjectsInfo");
 
 	mAlgorithmInfo->setCaption(": " + mCurrentAlgorithmCaptions[mCurrentAlgorithm]);
@@ -178,5 +181,6 @@
 	mHierarchyNodesInfo->setCaption(": 0");
 	mRenderedNodesInfo->setCaption(": 0");
-		
+	mNumObjectsInfo->setCaption(": 0");
+
     pOver->show();
 } 
@@ -332,4 +336,7 @@
 	mSceneMgr->getOption("NumRenderedNodes", &opt); sprintf(str,": %d", opt); 
 	mRenderedNodesInfo->setCaption(str);
+
+	sprintf(str,": %d", mTerrainContentGenerator->GetObjectCount()); 
+	mNumObjectsInfo->setCaption(str);
 }
 //-----------------------------------------------------------------------
@@ -97,5 +97,6 @@
 	mTerrainContentGenerator = new TerrainContentGenerator(mSceneMgr);
 	mTerrainContentGenerator->GenerateScene(300, "robot.mesh");
-	// no limitations now: the user can set objects also on peaks
+	// no limitations needed anymore: the user can set 
+	// objects also on peaks of terrain
 	mTerrainContentGenerator->SetMaxHeight(5000); 
 }